==> gitlab-foss-v18.7.0.tar.bz2: gitlab-foss-v18.7.0/spec/workers/packages/debian/generate_distribution_worker_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Packages::Debian::GenerateDistributionWorker, type: :worker, feature_category: :package_registry do
  describe '#perform' do
    subject { described_class.new.perform(container_type_as_string, distribution_id) }

    let(:container_type_as_string) { container_type.to_s }
    let(:distribution_id) { distribution.id }
    let(:subject2) { described_class.new.perform(container_type_as_string, distribution_id) }
    let(:subject3) { described_class.new.perform(container_type_as_string, distribution_id) }

    include_context 'with published Debian package'

    [:project, :group].each do |container_type|
      context "for #{container_type}" do
        include_context 'with Debian distribution', container_type

        context 'with mocked service' do
          it 'calls GenerateDistributionService' do
            expect(Gitlab::ErrorTracking).not_to receive(:log_exception)
            expect_next_instance_of(::Packages::Debian::GenerateDistributionService) do |service|
              expect(service).to receive(:execute)
                .with(no_args)
            end

            subject
          end
        end

        context 'with non existing distribution id' do
          let(:distribution_id) { non_existing_record_id }

          it 'returns early without error' do
            expect(Gitlab::ErrorTracking).not_to receive(:log_exception)
            expect(::Packages::Debian::GenerateDistributionService).not_to receive(:new)

            subject
          end
        end

        context 'with nil distribution id' do
          let(:distribution_id) { nil }

          it 'returns early without error' do
            expect(Gitlab::ErrorTracking).not_to receive(:log_exception)
            expect(::Packages::Debian::GenerateDistributionService).not_to receive(:new)

            subject
          end
        end

        context 'with valid parameters', quarantine: 'https://gitlab.com/gitlab-org/gitlab/-/issues/446272' do
          it_behaves_like 'an idempotent worker' do
            let(:job_args) { [container_type_as_string, distribution_id] }

            it_behaves_like 'Generate Debian Distribution and component files'
          end
        end
      end
    end
  end
end

==> gitlab-foss-v18.8.2.tar.bz2: gitlab-foss-v18.8.2/spec/workers/packages/debian/generate_distribution_worker_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Packages::Debian::GenerateDistributionWorker, type: :worker, feature_category: :package_registry do
  describe '#perform' do
    subject { described_class.new.perform(container_type_as_string, distribution_id) }

    let(:container_type_as_string) { container_type.to_s }
    let(:distribution_id) { distribution.id }
    let(:subject2) { described_class.new.perform(container_type_as_string, distribution_id) }
    let(:subject3) { described_class.new.perform(container_type_as_string, distribution_id) }

    include_context 'with published Debian package'

    [:project, :group].each do |container_type|
      context "for #{container_type}" do
        include_context 'with Debian distribution', container_type

        context 'with mocked service' do
          it 'calls GenerateDistributionService' do
            expect(Gitlab::ErrorTracking).not_to receive(:log_exception)
            expect_next_instance_of(::Packages::Debian::GenerateDistributionService) do |service|
              expect(service).to receive(:execute)
                .with(no_args)
            end

            subject
          end
        end

        context 'with non existing distribution id' do
          let(:distribution_id) { non_existing_record_id }

          it 'returns early without error' do
            expect(Gitlab::ErrorTracking).not_to receive(:log_exception)
            expect(::Packages::Debian::GenerateDistributionService).not_to receive(:new)

            subject
          end
        end

        context 'with nil distribution id' do
          let(:distribution_id) { nil }

          it 'returns early without error' do
            expect(Gitlab::ErrorTracking).not_to receive(:log_exception)
            expect(::Packages::Debian::GenerateDistributionService).not_to receive(:new)

            subject
          end
        end

        context 'with valid parameters',
          quarantine: 'https://gitlab.com/gitlab-org/quality/test-failure-issues/-/issues/17065' do
          it_behaves_like 'an idempotent worker' do
            let(:job_args) { [container_type_as_string, distribution_id] }

            it_behaves_like 'Generate Debian Distribution and component files'
          end

          # Error tests are outside the idempotent worker wrapper because
          # errors prevent re-execution, causing the idempotent check to fail
          it_behaves_like 'Debian Distribution key generation error'
        end
      end
    end
  end
end
